@@ -2,37 +2,38 @@
 """ Detect running daemons then configure and start the agent.
 """
 
+import agent_config
 import argparse
 import logging
 import os
+import platform
 import pwd
 import socket
 import subprocess
 import sys
-import platform
-
 import yaml
-import agent_config
-from detection.plugins import kafka
+from detection.plugins import ceilometer
+from detection.plugins import cinder
+from detection.plugins import glance
+from detection.plugins import kafka_consumer
+from detection.plugins import keystone
+from detection.plugins import libvirt
 from detection.plugins import mon
 from detection.plugins import mysql
-from detection.plugins import rabbitmq
 from detection.plugins import network
-from detection.plugins import zookeeper
-from detection.plugins import nova
-from detection.plugins import glance
-from detection.plugins import cinder
 from detection.plugins import neutron
+from detection.plugins import nova
+from detection.plugins import rabbitmq
 from detection.plugins import swift
-from detection.plugins import keystone
-from detection.plugins import ceilometer
+from detection.plugins import zookeeper
 from service import sysv
 
 # List of all detection plugins to run
-DETECTION_PLUGINS = [kafka.Kafka, mon.MonAPI, mon.MonPersister, mon.MonThresh, mysql.MySQL,
-                     rabbitmq.RabbitMQ, network.Network, nova.Nova, cinder.Cinder, swift.Swift,
-                     glance.Glance, ceilometer.Ceilometer, neutron.Neutron, keystone.Keystone,
-                     zookeeper.Zookeeper]
+DETECTION_PLUGINS = [ceilometer.Ceilometer, cinder.Cinder, glance.Glance,
+                     kafka_consumer.Kafka, keystone.Keystone, libvirt.Libvirt,
+                     mon.MonAPI, mon.MonPersister, mon.MonThresh, mysql.MySQL,
+                     network.Network, neutron.Neutron, nova.Nova,
+                     rabbitmq.RabbitMQ, swift.Swift, zookeeper.Zookeeper]
 # Map OS to service type
 OS_SERVICE_MAP = {'Linux': sysv.SysV}
 
@@ -99,7 +100,7 @@ def main(argv=None):
     agent_conf_path = os.path.join(args.config_dir, 'agent.conf')
     with open(os.path.join(args.template_dir, 'agent.conf.template'), 'r') as agent_template:
         with open(agent_conf_path, 'w') as agent_conf:
-            agent_conf.write(agent_template.read().format(args=args, hostname=socket.gethostname()))
+            agent_conf.write(agent_template.read().format(args=args, hostname=socket.getfqdn()))
     os.chown(agent_conf_path, 0, gid)
     os.chmod(agent_conf_path, 0o640)
     # Link the supervisor.conf
@@ -134,7 +135,7 @@ def main(argv=None):
         with open(config_path, 'w') as config_file:
             os.chmod(config_path, 0o640)
             os.chown(config_path, 0, gid)
-            config_file.write(yaml.dump(value))
+            config_file.write(yaml.safe_dump(value, encoding='utf-8', allow_unicode=True))
 
     # Now that the config is build start the service
     try:
